import { Injectable, UnauthorizedException } from '@nestjs/common';
import { RegisterDto } from './dto/registrer.dto';
import { LoginUserDto } from './dto/login-user.dto';
import { UserService } from 'src/user/user.service';
//import { JwtService } from '@nestjs/jwt';
import * as bcryptjs from "bcryptjs";

@Injectable()
export class AuthUserService {
  constructor(private readonly userService: UserService, 
  ) {}

  /*
  Metodo para registrar un usuario
  */
  async register({ name, lastname, email, password }: RegisterDto) {
    const hashedPassword = await bcryptjs.hash(password, 10);
    const userExists = await this.userService.findOneByEmail(email);
    if (userExists) {
      throw new UnauthorizedException('User already exists');
    }else{
      const user = await this.userService.create({
        name,
        lastname,
        email,
        password: hashedPassword,
      });
      return {
        message: 'User created',
        user,
      };
    }
  }

  /*
  Metodo para loguear un usuario
  */
  async login({ email, password }: LoginUserDto) {
    const user = await this.userService.findOneByEmail(email);
    if (!user) {
      throw new UnauthorizedException('Invalid email');
    }
    const passwordValida = await bcryptjs.compare(password, user.password);
    if (!passwordValida) {
      throw new UnauthorizedException('Invalid password');
    }
    return {
      message: 'User logged',
      user,
    };
    
  }

}
